@@ -14,6 +14,7 @@
 
 from __future__ import print_function, absolute_import
 
+import sys
 cmd_module = __import__("sys").modules["pymol.cmd"]
 from .cmd import _cmd, lock, unlock, Shortcut, \
      _feedback, fb_module, fb_mask, \
@@ -23,6 +24,7 @@ from .cmd import _cmd, lock, unlock, Shortcut, \
 import traceback
 import threading
 import os
+import pymol
 
 def model_to_sdf_list(self_cmd,model):
     from chempy import io
@@ -132,10 +134,18 @@ class CleanJob:
                 (fit_flag, sdf_list) = model_to_sdf_list(self_cmd,input_model)
                 input_sdf = ''.join(sdf_list)
 #                print input_sdf
+
+                if sys.version_info[0] > 2:
+                    input_sdf = input_sdf.encode()
+
                 result = mengine.run(input_sdf)
                 if result != None:
                     if len(result):
                         clean_sdf = result[0]
+
+                        if sys.version_info[0] > 2:
+                            clean_sdf = clean_sdf.decode()
+
                         clean_rec = clean_sdf.split("$$$$")[0]
                         clean_name = ""
                         self.energy = get_energy_from_rec(clean_rec)
@@ -197,7 +207,7 @@ class CleanJob:
             self_cmd.do("_ wizard")
 
 def _clean(selection, present='', state=-1, fix='', restrain='',
-          method='mmff', async=0, save_undo=1, message=None,
+          method='mmff', save_undo=1, message=None,
           _self=cmd_module):
 
     self_cmd = _self
@@ -251,15 +261,24 @@ def _clean(selection, present='', state=-1, fix='', restrain='',
         return None
 
 def clean(selection, present='', state=-1, fix='', restrain='',
-          method='mmff', async=0, save_undo=1, message=None,
-          _self=cmd_module):
-    if not int(async):
-        return _clean(selection,present,state,fix,restrain,method,async,save_undo,message,_self)
+          method='mmff', async_=0, save_undo=1, message=None,
+          _self=cmd_module, **kwargs):
+    if int(state) == 0:
+        raise pymol.CmdException('cleaning all states not supported')
+
+    async_ = int(kwargs.pop('async', async_))
+
+    if kwargs:
+        raise pymol.CmdException('unknown argument: ' + ', '.join(kwargs))
+
+    args = (selection, present, state, fix, restrain, method, save_undo, message, _self)
+
+    if not async_:
+        return _clean(*args)
     else:
         try:
             t = threading.Thread(target=_clean,
-                             args=(selection,present,state,fix,restrain,
-                                   method,async,save_undo,message,_self))
+                             args=args)
             t.setDaemon(1)
             t.start()
         except:
